#!/usr/bin/perl -w 
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;


use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Stats;
use Vhffs::Constants;
my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
#my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $domain_name = $cgi->param("NAME");
my $template;
my $output;
my $subtemplate;

my $templatedir = $vhffs->get_config->get_templatedir;

my $object;

if( $user->is_admin != 1 )
{
	
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "You are not allowed to see it");
	$template->param( MESSAGE => $message );
}
elsif( ! defined $domain_name )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "CGI ERROR !");
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined ( $object = new Vhffs::Services::Mail( $vhffs , $domain_name ) ) ) || ( $object->fetch < 0 ) )
{
	$template = new HTML::Template( filename => $templatedir."/misc/simplemsg.tmpl" );
	my $message = gettext( "Cannot fetch object");
	$template->param( MESSAGE => $message );
}
else
{
	$template = new HTML::Template( filename => $templatedir."/admin/mail/edit.tmpl" );

	$template->param( TITLE => gettext("Edit Mail Domain") .": " . $object->get_domain);


	$template->param( TEXT_DOMAIN => gettext("Domain") );
	$template->param( TEXT_CATCHALL => gettext("Catchall") );
	$template->param( TEXT_GROUP => gettext("Group") );
	$template->param( TEXT_OWNER => gettext("Owner") );
	$template->param( TEXT_STATUS => gettext("Status") );
	$template->param( TEXT_DESCRIPTION => gettext("Description") );
	$template->param( SEND => gettext("Send") );
	$template->param( TEXT_HISTORY => gettext("History") );

	$template->param( VALUE_DESCRIPTION => $object->get_description );
	$template->param( VALUE_DOMAIN => $object->get_domain );
	$template->param( VALUE_CATCHALL => $object->get_catchall );
	$template->param( VALUE_GROUP => Vhffs::Group::get_name_by_gid( $vhffs , $object->get_ownergid ));
	$template->param( VALUE_OWNER => Vhffs::User::get_name_by_uid( $vhffs , $object->get_owneruid ));

	my $oid = $object->{'object_id'};
	$template->param( VALUE_HISTORY => "/history.pl?OID=$oid" );

	$template->param( TEXT_FORWARD => gettext("Forward for") ." " . $object->get_domain );
	$template->param( TEXT_POPBOXES => gettext("Popboxes for") ." " . $object->get_domain );


    $output = "";
    my $forwards = $object->get_forwards;
    foreach( keys %{$forwards} )
    {
		$subtemplate = new HTML::Template( filename => $templatedir."/admin/mail/admin_forward.tmpl" );
		$subtemplate->param( LOCAL_PART => $_ . "\@" . $object->get_domain );
		$subtemplate->param( DOMAIN => $object->get_domain );
		$subtemplate->param( FORWARD_MAIL => $forwards->{$_}{'remote_name'} );
		$subtemplate->param( LOCALPART => $_ );
		$subtemplate->param( TEXT_MODIFY_FORWARD => gettext( "Change forward" ) );
		$subtemplate->param( TEXT_DELETE => gettext( "Delete this mail account" ) );
		$output .= $subtemplate->output;        
	}       
	$template->param( FORWARDS => $output );



	$output = "";
	my $boxes = $object->get_boxes;
	foreach( keys %{$boxes} )
	{
		$subtemplate = new HTML::Template( filename => $templatedir."/admin/mail/admin_box.tmpl" );
		$subtemplate->param( ACCOUNT => $_ . "\@" . $object->get_domain );
		$subtemplate->param( TEXT_CHANGE_PASSWORD => gettext( "Change Password" ) );
		$subtemplate->param( LOCALPART => $_ );
		$subtemplate->param( TEXT_DELETE => gettext( "Delete this forward" ) );
		$subtemplate->param( DOMAIN => $object->get_domain );

		$output .= $subtemplate->output;
	}       

	$template->param( POPBOXES => $output );





	$template->param( TEXT_STATUS_WAITING_FOR_VALIDATION => gettext("Waiting for validation") );
	$template->param( TEXT_STATUS_VALIDATION_REFUSED => gettext("Validation refused") );
	$template->param( TEXT_STATUS_WAITING_FOR_CREATION => gettext("Waiting for creation") );
	$template->param( TEXT_STATUS_CREATING_ERROR => gettext("Creating error") );
	$template->param( TEXT_STATUS_ACTIVATED => gettext("Activated") );
	$template->param( TEXT_STATUS_CREATED => gettext("Created") );
	$template->param( TEXT_STATUS_SUSPENDED => gettext("Suspended") );
	$template->param( TEXT_STATUS_SUSPENDED_BEFORE_DELETED => gettext("Suspended") );
	$template->param( TEXT_STATUS_WAITING_FOR_MODIFICATION => gettext("Waiting for modification") );
	$template->param( TEXT_STATUS_MODIFICATION_ERROR => gettext("Modification error") );
	$template->param( TEXT_STATUS_MODIFICATION_APPLIED => gettext("Modification applied") );
	$template->param( TEXT_STATUS_TO_DELETE => gettext("Will be deleted") );


	$template->param( VALUE_STATUS_WAITING_FOR_VALIDATION => Vhffs::Constants::WAITING_FOR_VALIDATION );
	$template->param( VALUE_STATUS_VALIDATION_REFUSED => Vhffs::Constants::VALIDATION_REFUSED );
	$template->param( VALUE_STATUS_WAITING_FOR_CREATION => Vhffs::Constants::WAITING_FOR_CREATION );
	$template->param( VALUE_STATUS_CREATING_ERROR => Vhffs::Constants::CREATING_ERROR );
	$template->param( VALUE_STATUS_ACTIVATED => Vhffs::Constants::ACTIVATED );
	$template->param( VALUE_STATUS_CREATED => Vhffs::Constants::CREATED );
	$template->param( VALUE_STATUS_SUSPENDED => Vhffs::Constants::SUSPENDED );
	$template->param( VALUE_STATUS_SUSPENDED_BEFORE_DELETED => Vhffs::Constants::SUSPENDED_BEFORE_DELETED );
	$template->param( VALUE_STATUS_WAITING_FOR_MODIFICATION => Vhffs::Constants::WAITING_FOR_MODIFICATION );
	$template->param( VALUE_STATUS_MODIFICATION_ERROR => Vhffs::Constants::MODIFICATION_ERROR );
	$template->param( VALUE_STATUS_MODIFICATION_APPLIED => Vhffs::Constants::MODIFICATION_APPLIED );
	$template->param( VALUE_STATUS_TO_DELETE => Vhffs::Constants::TO_DELETE );

	my $status = $object->get_status;

	if( $status == Vhffs::Constants::WAITING_FOR_VALIDATION )
	{
		$template->param( SELECTED_STATUS_WAITING_FOR_VALIDATION => "selected" );
	}
	elsif( $status == Vhffs::Constants::VALIDATION_REFUSED )
	{
		$template->param( SELECTED_STATUS_VALIDATION_REFUSED => "selected" );
	}
	elsif( $status == Vhffs::Constants::WAITING_FOR_CREATION )
	{
		$template->param( SELECTED_STATUS_WAITING_FOR_CREATION => "selected" );
	}
	elsif( $status == Vhffs::Constants::CREATING_ERROR )
	{
		$template->param( SELECTED_STATUS_CREATING_ERROR => "selected" );
	}
	elsif( $status == Vhffs::Constants::CREATED )
	{
		$template->param( SELECTED_STATUS_CREATED => "selected" );
	}
	elsif( $status == Vhffs::Constants::ACTIVATED )
	{
		$template->param( SELECTED_STATUS_ACTIVATED => "selected" );
	}
	elsif( $status == Vhffs::Constants::SUSPENDED )
	{
		$template->param( SELECTED_STATUS_SUSPENDED => "selected" );
	}
	elsif( $status == Vhffs::Constants::SUSPENDED_BEFORE_DELETED )
	{
		$template->param( SELECTED_STATUS_SUSPENDED_BEFORE_DELETED => "selected" );
	}
	elsif( $status == Vhffs::Constants::WAITING_FOR_MODIFICATION )
	{
		$template->param( SELECTED_STATUS_WAITING_FOR_MODIFICATION => "selected" );
	}
	elsif( $status == Vhffs::Constants::MODIFICATION_ERROR )
	{
		$template->param( SELECTED_STATUS_MODIFICATION_ERROR => "selected" );
	}
	elsif( $status == Vhffs::Constants::MODIFICATION_APPLIED )
	{
		$template->param( SELECTED_STATUS_MODIFICATION_APPLIED => "selected" );
	}
	elsif( $status == Vhffs::Constants::TO_DELETE )
	{
		$template->param( SELECTED_STATUS_TO_DELETE => "selected" );
	}

}

display Vhffs::Panel::Main($panel, $template->output);
