#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.


use POSIX qw(locale_h);
use HTML::Template;
use locale;
use Locale::gettext;
use CGI;
use CGI::Session;
use strict;

use Vhffs::User;
use Vhffs::Group;
use Vhffs::Main;
use Vhffs::Panel::Main;
use Vhffs::Panel::Menu;
use Vhffs::Services::LargeFile;

my $panel = new Vhffs::Panel::Main();
if(!$panel)  {
        exit 0;
}

my $vhffs = $panel->{'vhffs'};
my $session = $panel->{'session'};
my $maintemplate = $panel->{'template'};
my $user = $panel->{'user'};
my $group = $panel->{'group'};
my $projectname = $session->param("project");
my $cgi = $panel->{'cgi'};
my $cgigroupname = $cgi->param('cgigroup');
my $filename = $cgi->param("name");
my $template;
my $output;
my $subtemplate;
my $file;
my $message;

if( defined $cgigroupname )
{
	$group = new Vhffs::Group( $vhffs , $cgigroupname , '401' );
	$group->fetch;
}

$file = new Vhffs::Services::LargeFile( $vhffs , $filename  , undef , $group );


if( ( ! defined $filename ) || ( ! defined $file ) )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
	$message = gettext( "CGI Error" );
	$template->param( MESSAGE => $message );
}
elsif( ( ! defined $group ) || ( $group->fetch < 0 ) )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
	$template->param( MESSAGE => gettext("Grant an user access to this repository") );
}
elsif( $file->fetch < 0 )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
	$message = gettext( "Cannot get informations on this object");
	$template->param( MESSAGE => $message );

}
elsif( ( Vhffs::Acl::what_perm_for_user( $user , $file , $vhffs ) < Vhffs::Constants::ACL_VIEW ) && ( $user->is_admin != 1 ) )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
	$message = gettext( "You're not allowed to do this (ACL rights)");
	$template->param( MESSAGE => $message );
}
elsif( ( ( $file->get_status != Vhffs::Constants::ACTIVATED ) || ( $file->get_status != Vhffs::Constants::CREATED ) )&& ( $user->is_admin != 1 ) )
{
	$template = open_template( $vhffs , "misc" , "simplemsg" );
    $message = gettext( "This object is not functionnal yet. Please wait creation, moderation or modification.");
	$template->param( MESSAGE => $message );
}
else
{
	if( $file->get_status == Vhffs::Constants::CREATED )
	{
		$template = open_template( $vhffs , 'largefile' , 'prefs-waiting' );
		$template->param( VALUE_FILENAME => $file->get_filename() );

		$template->param( TEXT_TITLE => gettext("Hosted file administration") );
	
	
		$template->param( 'NOT-ACTIVE' => gettext("This file is not active yet") );
		$template->param( 'TEXT-EXPLAIN' => gettext("Your file is not active at this time. In fact, you need upload it and declare it uploaded on the panel (see following instructions). You probably received a mail with all instructions to upload the file on our servers.") );
	
		$template->param( 'TITLE-SEND-INFOS' => gettext("Send me informations back") );
		$template->param( 'TITLE-COMPLETE'  => gettext( "Declare the file as uploaded and complete" ) );
	
		$template->param( 'TEXT-INFOS' => gettext("All instructions were sended to you. But you may forgot these informations. Click on the link, and we will send them again. Be careful, it takes lot of time. ") );
		$template->param( 'CONFIRM-INFOS' => gettext("Yes, I want instructions back") );


		$template->param( 'TEXT-COMPLETE' => gettext("If your file has been uploaded and seems to be complete, you can declare it as uploaded. Once done, we will add it on our public servers and will be mirrored all around the world.") );
		$template->param( 'CONFIRM-COMPLETE' => gettext("Yes, my file was successfully uploaded") );

	}
	else
	{
		$template = open_template( $vhffs , 'largefile' , 'prefs' );

		$template->param( TEXT_TITLE => gettext("Hosted file administration") );
	
	
		$template->param( TEXT_FILENAME => gettext("Filename") );
		$template->param( VALUE_FILENAME => $file->get_filename() );
	
		$template->param( TEXT_LICENCE => gettext("License") );
		$template->param( VALUE_LICENCE => $file->get_licence() );
	
		$template->param( TEXT_FILESIZE => gettext("Size") );
		$template->param( VALUE_FILESIZE => $file->get_size() );
	
		$template->param( TEXT_FILETYPE => gettext("Type") );
		$template->param( VALUE_FILETYPE => $file->get_type() );
	
		$template->param( TEXT_DELETE_FILENAME => gettext("Delete this file from servers") );
		$template->param( TEXT_BEFORE_DELETE => gettext("This action is non-reversible.") );
		$template->param( ASK_DELETE_FILENAME => gettext("If you delete this file, we will delete the file from our servers.") );
		$template->param( YES => gettext("Yes I'm sure of what I do") );
		$template->param( NO => gettext("No, I'm not sure, I prefer to keep this project.") );
		$template->param( TEXT_DELETE => gettext("Delete") );
	
		$template->param( TEXT_ACL_ADMIN => "Admin Rights on this object (ACL)" );
		$template->param( EXPLAIN_ADMIN_ACL => "You can Manage rights on this service for each user in the VHFFS database. Please read help before manage it." );
		$template->param( ADMIN_ACL => "Ok, go to ACL admin" );
	}

	if( $user->is_admin == 1 )
	{
		$subtemplate = open_template( $vhffs , "admin" , "misc" , "opart" );
		$subtemplate->param( OID => $file->get_oid );
		$subtemplate->param( OPART_TEXT => gettext("Go to object-part admin") );
		$subtemplate->param( OPART_TITLE => gettext("Object part") );
		$template->param( OPART => $subtemplate->output );
	}
	
}

display($panel, $template->output );
