#!/usr/bin/perl
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use Vhffs::Main;
use Vhffs::User;
use Vhffs::Group;
use Vhffs::Robots::Group;
use Vhffs::Robots;



my $user;
my $group;
my $name;
my $vhffs = init Vhffs::Main;

Vhffs::Robots::lock( $vhffs );

my $joins = Vhffs::Robots::Group::getall_user_group_to_create( $vhffs );

if( defined $joins )
{
foreach( keys %{$joins} )
{
	$name = Vhffs::Group::get_name_by_gid( $vhffs , $_ );
	$group = new Vhffs::Group( $vhffs , $name ,  '401' );
	if( ( defined $group ) && ( $group->fetch > 0 ) )
	{
		$name = Vhffs::User::get_name_by_uid( $vhffs , $joins->{$_}{'uid'} );
		$user = new Vhffs::User( $vhffs , $name , '401' );

		if( ( defined $user ) && ( $user->fetch > 0 ) )
		{
			if( Vhffs::Robots::Group::add_user( $user , $group , $vhffs ) < 0 )
			{
				Vhffs::Robots::vhffs_log( sprintf( "Error adding user %s to group %s" , $user->get_username , $group->get_groupname ), $vhffs);
			}
			else
			{
				Vhffs::Robots::vhffs_log( sprintf( "Add user %s to group %s" , $user->get_username , $group->get_groupname ), $vhffs);
			}
			
		}
		else
		{
			Vhffs::Robots::vhffs_log( sprintf( "Cannot get user %s" , $_ ), $vhffs);
		}
	}
	else
	{
		Vhffs::Robots::vhffs_log( sprintf( "Cannot get user %s" , $_ ), $vhffs);
	}
}
}



$joins = Vhffs::Robots::Group::getall_user_group_to_delete( $vhffs );

if( ! defined $joins )
{
	Vhffs::Robots::unlock( $vhffs );
	exit( 1 );
}

foreach( keys %{$joins} )
{
	$name = Vhffs::Group::get_name_by_gid( $vhffs , $_ );
	$group = new Vhffs::Group( $vhffs , $name ,  '401' );
	if( ( defined $group ) && ( $group->fetch > 0 ) )
	{
		$name = Vhffs::User::get_name_by_uid( $vhffs , $joins->{$_}{'uid'} );
		$user = new Vhffs::User( $vhffs , $name , '401' );

		if( ( defined $user ) && ( $user->fetch > 0 ) )
		{
			Vhffs::Robots::vhffs_log( sprintf( "Remove user %s from group %s" , $user->get_username , $group->get_groupname ), $vhffs);
			Vhffs::Robots::Group::del_user( $user , $group , $vhffs );
			
		}
		else
		{
			Vhffs::Robots::vhffs_log( sprintf( "Cannot get user %s" , $name ), $vhffs);
		}
	}
	else
	{
		Vhffs::Robots::vhffs_log( sprintf( "Cannot get group %s" , $_ ), $vhffs);
	}
}

Vhffs::Robots::unlock( $vhffs );

exit 0;
